@@ -1,3 +1,3 @@
 import amethyst_facet
 if __name__ == "__main__":
-    amethyst_facet.facet.facet()
\ No newline at end of file
+    amethyst_facet.cli.commands.facet()
\ No newline at end of file
